Hans Leidekker : wininet: Rename a function to better match what it does.

Alexandre Julliard julliard at winehq.org
Mon Feb 18 08:50:44 CST 2008


Module: wine
Branch: master
Commit: 9717113fcb337dc2bbd5dbacf74115babe0c216c
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=9717113fcb337dc2bbd5dbacf74115babe0c216c

Author: Hans Leidekker <hans at it.vu.nl>
Date:   Sun Feb 17 21:29:45 2008 +0100

wininet: Rename a function to better match what it does.

---

 dlls/wininet/http.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/dlls/wininet/http.c b/dlls/wininet/http.c
index 63491d0..9e02d69 100644
--- a/dlls/wininet/http.c
+++ b/dlls/wininet/http.c
@@ -307,7 +307,7 @@ static LPWSTR HTTP_BuildHeaderRequestString( LPWININETHTTPREQW lpwhr, LPCWSTR ve
     return requestString;
 }
 
-static void HTTP_ProcessHeaders( LPWININETHTTPREQW lpwhr )
+static void HTTP_ProcessCookies( LPWININETHTTPREQW lpwhr )
 {
     static const WCHAR szSet_Cookie[] = { 'S','e','t','-','C','o','o','k','i','e',0 };
     int HeaderIndex;
@@ -842,8 +842,8 @@ BOOL WINAPI HttpEndRequestW(HINTERNET hRequest,
     SendAsyncCallback(&lpwhr->hdr, lpwhr->hdr.dwContext,
             INTERNET_STATUS_RESPONSE_RECEIVED, &responseLen, sizeof(DWORD));
 
-    /* process headers here. Is this right? */
-    HTTP_ProcessHeaders(lpwhr);
+    /* process cookies here. Is this right? */
+    HTTP_ProcessCookies(lpwhr);
 
     dwBufferSize = sizeof(lpwhr->dwContentLength);
     if (!HTTP_HttpQueryInfoW(lpwhr,HTTP_QUERY_FLAG_NUMBER|HTTP_QUERY_CONTENT_LENGTH,
@@ -2676,7 +2676,7 @@ BOOL WINAPI HTTP_HttpSendRequestW(LPWININETHTTPREQW lpwhr, LPCWSTR lpszHeaders,
                                 INTERNET_STATUS_RESPONSE_RECEIVED, &responseLen,
                                 sizeof(DWORD));
 
-            HTTP_ProcessHeaders(lpwhr);
+            HTTP_ProcessCookies(lpwhr);
 
             dwBufferSize = sizeof(lpwhr->dwContentLength);
             if (!HTTP_HttpQueryInfoW(lpwhr,HTTP_QUERY_FLAG_NUMBER|HTTP_QUERY_CONTENT_LENGTH,




More information about the wine-cvs mailing list